@@ -1,20 +1,17 @@
 from .contract import Contract
 from .abigen import abigen
 from .client import Client
-from .anchor import Anchor
-from .wcw import WCW
 from .multisigclient import MultiSigClient
-
+from .paywith import Payers
 
 __all__ = [
     'Contract', 
     'Client',
     'MultiSigClient',
-    'Anchor',
-    'WCW',
+    'Payers',
     'abigen'
 ]
 
 __author__ = 'abuztrade'
-__version__ = '0.0.1'
+__version__ = '0.0.8'
 __email__ = 'abuztrade.work@gmail.com'
\ No newline at end of file
